@@ -1,5 +1,5 @@
 from xefab.collection import XefabCollection
-
+from xefab.tasks import utils
 from .jupyter_task import start_jupyter
 from .squeue_task import squeue
 from .transfer_tasks import download_file, upload_file
@@ -16,3 +16,4 @@ namespace.add_task(start_jupyter)
 namespace.add_task(download_file)
 namespace.add_task(upload_file)
 namespace.add_task(submit_job)
+namespace.add_task(utils.show_context)
