@@ -1,4 +1,5 @@
 from xefab.collection import XefabCollection
+from xefab.tasks import utils
 
 from .jupyter_task import start_jupyter
 from .squeue_task import squeue
@@ -23,3 +24,4 @@ namespace.add_task(start_jupyter)
 namespace.add_task(download_file)
 namespace.add_task(upload_file)
 namespace.add_task(submit_job)
+namespace.add_task(utils.show_context)
