@@ -12,14 +12,14 @@ def printable(d):
 
 
 @task
-def show_config(c, config_name: str = None):
-    """Get a config from the config server."""
+def show_context(c, config_name: str = None):
+    """Show the context being used for tasks."""
     if config_name is None:
-        console.print_json(data=printable(c.config), indent=4)
+        console.print_json(data=printable(c), indent=4)
         return
-    result = getattr(c.config, config_name, None)
+    result = getattr(c, config_name, None)
     if result is None:
-        result = c.config.get(config_name, None)
+        result = c.get(config_name, None)
     if result is None:
         console.print(f"Config {config_name} not found.")
     result = printable(result)
